#
# spec file for package python-lmdb
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-lmdb
Version:        1.5.1
Release:        3.0.2.1.sr20241103
Summary:        Universal Python binding for the LMDB 'Lightning' Database
License:        OLDAP-2.8
Group:          Development/Languages/Python
URL:            https://github.com/dw/py-lmdb/
Source:         https://files.pythonhosted.org/packages/source/l/lmdb/lmdb-%{version}.tar.gz
Patch1:         https://github.com/jnwatson/py-lmdb/pull/368/commits/206a3754466397baeb418e70be9d35b12cc4079f.patch#/py313-support.patch
BuildRequires:  %{python_module cffi}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  lmdb-devel
BuildRequires:  python-rpm-macros
%python_subpackages

%description
This is a universal Python binding for the LMDB 'Lightning' Database.

LMDB is a tiny database with the following properties:
  * Ordered map interface (keys are always lexicographically sorted).
  * Reader/writer transactions: readers don’t block writers,
    writers don’t block readers.
    Each environment supports one concurrent write transaction.
  * Cheap read transactions.
  * Environments may be opened by multiple processes on the same host.
  * Multiple named databases may be created with transactions covering
    all named databases.
  * Memory mapped, allowing for zero copy lookup and iteration.
    This is optionally exposed to Python using the buffer() interface.
  * Maintenance requires no external process or background threads.
  * No application-level caching is required:
    LMDB uses the operating system’s buffer cache.

%prep
%autosetup -p1 -n lmdb-%{version}

%build
export LMDB_FORCE_SYSTEM=1
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%license LICENSE
%doc README.md ChangeLog
%{python_sitearch}/lmdb
%{python_sitearch}/lmdb-%{version}.dist-info

%changelog
* Wed Nov 20 2024 Ben Greiner <code@bnavigator.de>
- Modernize specfile
* Tue Nov 19 2024 Dirk Müller <dmueller@suse.com>
- add py313-support.patch to fix build with py313
* Mon Jul  1 2024 Mia Herkt <mia@0x0.st>
- Update to 1.5.1 (no changes for openSUSE)
* Thu Apr  6 2023 Mia Herkt <mia@0x0.st>
- Update to v1.4.1
  * Fix a documentation typo
* Tue Dec 13 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v1.4.0
  * Update manifest and a copyright
* Mon Jan 31 2022 Mia Herkt <mia@0x0.st>
- Update to v1.3.0
  * Add Python 3.10 support.
  * Fix crash relating to caching of transactions.
  The 'max_spare_txns' parameter to Environment/open is currently
  ignored.
* Tue Apr 20 2021 Mia Herkt <mia@0x0.st>
- Update to v1.2.1 (no changes)
* Sun Apr 18 2021 Mia Herkt <mia@0x0.st>
- Update to v1.2.0
  * Remove wheel generation for 2.7 because the manylinux images
    no longer support it.
  * Allow passing None as a value to transaction.del in CFFI
    implementation for parity with cpython implementation.
  * Fix Cursor.put behavior on a dupsort DB with append=True.
  * Add warning to docs about use of Environment.set_mapsize.
    This is currently an unresolved issue with upstream LMDB.
  * CFFI implementation:
    fix a seg fault when open_db returns map full.
  * CFFI implementation:
    fix a bug in open_db in a read-only environment.
* Fri Feb  5 2021 Mia Herkt <mia@0x0.st>
- Update to v1.1.0
  * Prevent invalid flag combinations when creating a database.
  * Add a Cursor.getmulti method with optional buffer support.
* Sun Oct 11 2020 Mia Herkt <mia@0x0.st>
- Update to v1.0.0
  * Start of new semantic versioning scheme.  This would be a minor
    version bump from the 0.99 release if it were semantically
    versioned.
  * Allow environment copy to take a passed-in transaction.
    This is the first released feature that requires a (very small)
    patch to the underlying C library.  By default, the patch will
    be applied unless this module is built with LMDB_PURE
    environment variable set.
* Mon Aug 17 2020 Michael Ströder <michael@stroeder.com>
- Update to v0.99
  * Fix lmdb.tool encoding issues.
  * Fix -l lmdb invocation issue.
  * Minor documentation improvements.
  * Update LMDB to version 0.9.24.
  * Update for Python 3.9 (current release candidate) support.
  * Resolve a bug when using cursor.putmulti and append=True on dupsort DBs.
  * Allow _Database.flags method to take no arguments since the one argument
    wasn't being used.
* Tue Nov 26 2019 Martin Herkt <9+suse@cirno.systems>
- Update to v0.98
  * Fix that a duplicate argument to a lmdb method would cause
    an assert.
  * Fix crash under debug cpython when mdb_cursor_open failed
* Mon Aug 12 2019 Martin Herkt <9+suse@cirno.systems>
- Update to v0.97
  * Fix a missed GIL unlock sequence.
  * Fix argv check in JEP (cpython under Java) environment.
* Wed Jul 24 2019 Martin Herkt <9+suse@cirno.systems>
- Update to v0.96
  * Doc updates.
  * More removal of code for now-unsupported Python versions.
  * Only preload the value with the GIL unlocked when the value is
    actually requested. This significantly improves read
    performance to retrieve keys with large values when the value
    isn't retrieved.
* Sun Jun  9 2019 Martin Herkt <9+suse@cirno.systems>
- Update to v0.95
  * Handling of the Environment(create=True) flag was improved.
  * Database names may be reused after they are dropped on CFFI,
    without reopening the environment.
* Mon May 21 2018 9+suse@cirno.systems
- Update to v0.94
  * CPython argument parsing now matches the behaviour of CFFI,
    and most sane  Python APIs: a bool parameter is considered
    to be true if it is any truthy value, not just if it is
    exactly True.
  * Fixed several 2.7/3 bugs in command line tool.
* Mon May 21 2018 9+suse@cirno.systems
- Use system liblmdb
* Fri Aug 11 2017 9@cirno.systems
- Add doc files
* Fri Aug  4 2017 9@cirno.systems
- Init package, v0.93
